@@ -58,7 +58,8 @@ class GetApexClassCompletionsCommand(Command):
         Returns list of completions given a string of Apex
     """
     def execute(self):
-        data = self.params.get("data", None)
+        text_buffer = self.params.get("buffer", None)
+        point = self.params.get("point", None)
         word = self.params.get("word", None)
         file_name = self.params.get("file_name", None)
         
@@ -75,13 +76,22 @@ class GetApexClassCompletionsCommand(Command):
         #         String s = 'foo';
         #         s.
 
-        if data == None:
-            raise MMException('Please provide data')
-        if file_name == None:
-            raise MMException('Please provide file_name')
+        # if data == None:
+        #     raise MMException('Please provide data')
+        # if file_name == None:
+        #     raise MMException('Please provide file_name')
 
         apex_completions = util.parse_json_from_file(os.path.join(config.base_path, config.support_dir, "sforce", "metadata", "apex.json"))
-        typedef = parsehelp.get_type_definition(data)
+        
+        # point passed
+        lines = text_buffer.split('\n')
+        substr = ''
+        for i, val in enumerate(lines):
+            if i <= point[0]:
+                substr += val
+
+        debug(substr)
+        typedef = parsehelp.get_type_definition(substr)
         
         debug('autocomplete type definition: ')
         debug(typedef)
