@@ -48,6 +48,10 @@ class MavensMateRequestHandler():
             the session holds information about the plugin running it
             and establishes a project object
         """    
+        # print 'PAYLOAD ---->'
+        # print self.payload
+        # print type(self.payload)
+
         if self.payload != None and type(self.payload) is dict and 'settings' in self.payload:
             config.plugin_client_settings = self.payload['settings']
         config.offline = self.args.offline
@@ -183,8 +187,8 @@ def get_request_payload():
     try:
         if sys.stdin.isatty():
             return {}
-        return json.loads(sys.stdin.read())
-    except ValueError:
+        return json.loads(sys.stdin.read(), strict=False) #strict=False to allow new line chars
+    except ValueError, e:
         return {}
 
 def get_available_commands():
